@@ -1,17 +1,20 @@
 package App::Google::Docs::Command::list;
 BEGIN {
-  $App::Google::Docs::Command::list::VERSION = '0.07';
+  $App::Google::Docs::Command::list::VERSION = '0.08';
 }
 
 use App::Google::Docs -command;
 
+use warnings;
+use strict;
+
 =head1 NAME
 
 App::Google::Docs::Command::list - List your docs
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
